/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl;

import javax.management.ObjectName;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.jmx.api.api.InstallerComponentClient;
import org.ow2.petals.jmx.api.api.configuration.component.InstallationConfigurationComponentClient;
import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentDoesNotExistException;
import org.ow2.petals.jmx.api.api.configuration.component.exception.ConfigurationComponentErrorException;
import org.ow2.petals.jmx.api.api.exception.InstallerComponentErrorException;
import org.ow2.petals.jmx.api.impl.mbean.Installer;
import org.ow2.petals.jmx.api.impl.mbean.InstallerResults;

/**
 * <p>
 * Unit tests of {@link InstallerComponentClient} to check that JMX client interfaces are aligned with the JMX server
 * MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link InstallerComponentClient} to avoid to forget some methods. A unit test will only
 * invoke the associated method of {@link InstallerComponentClient}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class InstallerComponentClientImplTest extends AbstractServiceClientImpl implements InstallerComponentClient {

    private InstallerComponentClient installerComponentClient;

    @Before
    public void before() throws Exception {
        this.embeddedJmxSrvCon.registerInstallerComponentService(new Installer(new InstallerResults()), COMPONENT_ID);
        this.installerComponentClient = jmxClient.getInstallerComponentClient(COMPONENT_ID);
    }

    /**
     * Check the interface consistency of {@link InstallerComponentClient#install()}
     */
    @Test
    public void testInstall() throws InstallerComponentErrorException {

        this.install();
    }

    @Override
    public void install() throws InstallerComponentErrorException {

        this.installerComponentClient.install();
    }

    /**
     * Check the interface consistency of {@link InstallerComponentClient#uninstall()}
     */
    @Test
    public void testUninstall() throws InstallerComponentErrorException {

        this.uninstall();
    }

    @Override
    public void uninstall() throws InstallerComponentErrorException {

        this.installerComponentClient.uninstall();
    }

    /**
     * Check the interface consistency of {@link InstallerComponentClient#isInstalled()}
     */
    @Test
    public void testIsInstalled() throws InstallerComponentErrorException {

        this.isInstalled();
    }

    @Override
    public boolean isInstalled() throws InstallerComponentErrorException {

        return this.installerComponentClient.isInstalled();
    }

    /**
     * Check the interface consistency of {@link InstallerComponentClient#getInstallRoot()}
     */
    @Test
    public void testGetInstallRoot() throws InstallerComponentErrorException {

        this.getInstallRoot();
    }

    @Override
    public String getInstallRoot() throws InstallerComponentErrorException {

        return this.installerComponentClient.getInstallRoot();
    }

    /**
     * Check the interface consistency of {@link InstallerComponentClient#getMBeanName()}
     */
    @Test
    public void testGetMBeanName() throws InstallerComponentErrorException {

        this.getMBeanName();
    }

    @Override
    public ObjectName getMBeanName() {

        return this.installerComponentClient.getMBeanName();
    }

    /**
     * Check the interface consistency of {@link InstallerComponentClient#getInstallationConfigurationClient()}
     */
    @Test
    public void testGetConfigurationInstallerClient() throws InstallerComponentErrorException,
            ConfigurationComponentDoesNotExistException, ConfigurationComponentErrorException {

        this.getInstallationConfigurationClient();
    }

    @Override
    public InstallationConfigurationComponentClient getInstallationConfigurationClient()
            throws ConfigurationComponentDoesNotExistException, ConfigurationComponentErrorException,
            InstallerComponentErrorException {

        return this.installerComponentClient.getInstallationConfigurationClient();
    }

    @Override
    public <T> T getInstallationConfigurationClient(Class<T> clazz) throws ConfigurationComponentDoesNotExistException,
            InstallerComponentErrorException {
        return this.installerComponentClient.getInstallationConfigurationClient(clazz);
    }

}
