/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl;

import java.util.logging.Logger;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.clientserverapi.system.logging.exception.LoggingServiceException;
import org.ow2.petals.jmx.api.api.LoggerServiceClient;
import org.ow2.petals.jmx.api.api.exception.LoggerServiceErrorException;
import org.ow2.petals.jmx.api.impl.mbean.LoggingService;
import org.ow2.petals.jmx.api.impl.mbean.LoggingServiceMBean;

/**
 * <p>
 * Unit tests of {@link LoggerServiceClientImpl} to check that JMX client interfaces are aligned with the JMX server
 * MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link LoggingServiceMBean} to avoid to forget some methods. A unit test will only invoke
 * the associated method of {@link LoggingServiceMBean}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class LoggerServiceClientImplTest extends AbstractServiceClientImpl implements
 LoggerServiceClient {

    // A logger must be registered into Java logging
    private static final Logger LOG = Logger.getLogger(LoggerServiceClientImplTest.class.getName());

    private LoggerServiceClient loggerServiceClient;

    @Before
    public void before() throws Exception {
        this.embeddedJmxSrvCon.registerLoggerService(new LoggingService());
        this.loggerServiceClient = jmxClient.getLoggerServiceClient();
    }

    /**
     * Check the interface consistency of {@link LoggerServiceClientImpl#setLoggerLevel(String, String)}
     */
    @Test
    public void testSetLoggerLevel() throws LoggerServiceErrorException {
        this.setLoggerLevel(LoggerServiceClientImplTest.class.getName(), "INFO");
    }

    @Override
    public void setLoggerLevel(final String logger, final String level) throws LoggerServiceErrorException {
        this.loggerServiceClient.setLoggerLevel(logger, level);
    }

    /**
     * Check the interface consistency of {@link LoggerServiceClientImpl#getLoggerLevel(String)}
     */
    @Test
    public void testGetLoggerLevel() throws LoggerServiceErrorException {
        this.getLoggerLevel(LoggerServiceClientImplTest.class.getName());
    }

    @Override
    public String getLoggerLevel(final String logger) throws LoggerServiceErrorException {
        return this.loggerServiceClient.getLoggerLevel(logger);
    }

    /**
     * Check the interface consistency of {@link LoggerServiceClientImpl#getLevels()}
     */
    @Test
    public void testGetLevels() throws LoggingServiceException {
        this.getLevels();
    }

    @Override
    public String[] getLevels() throws LoggingServiceException {
        return this.loggerServiceClient.getLevels();
    }

    /**
     * Check the interface consistency of {@link LoggerServiceClientImpl#getLoggers()}
     */
    @Test
    public void testGetLoggers() throws LoggingServiceException {
        this.getLoggers();
    }

    @Override
    public String[][] getLoggers() throws LoggingServiceException {
        return this.loggerServiceClient.getLoggers();
    }

}
