/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.Properties;

import javax.management.InstanceAlreadyExistsException;
import javax.management.MBeanRegistrationException;
import javax.management.NotCompliantMBeanException;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.jmx.api.api.PetalsAdminServiceClient;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.exception.PetalsAdminDoesNotExistException;
import org.ow2.petals.jmx.api.api.exception.PetalsAdminServiceErrorException;
import org.ow2.petals.jmx.api.impl.mbean.PetalsAdminService;
import org.ow2.petals.jmx.api.impl.mbean.PetalsAdminServiceMBean;

/**
 * <p>
 * Unit tests of {@link PetalsAdminServiceClientImpl} to check that JMX client interfaces are aligned with the JMX
 * server MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link PetalsAdminServiceMBean} to avoid to forget some methods. A unit test will only
 * invoke the associated method of {@link PetalsAdminServiceMBean}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class PetalsAdminServiceClientImplTest extends AbstractServiceClientImpl implements PetalsAdminServiceMBean {

    public final static boolean PING_RESULT = Boolean.TRUE.booleanValue();

    private PetalsAdminServiceClient petalsAdminServiceClient;

    @Before
    public void before() throws Exception {
        this.embeddedJmxSrvCon.registerPetalsAdminService(new PetalsAdminService(PING_RESULT));
        this.petalsAdminServiceClient = jmxClient.getPetalsAdminServiceClient();
    }

    /**
     * Check the interface consistency of {@link PetalsAdminServiceClientImpl#ping()}
     */
    @Test
    public void testPing() throws PetalsAdminDoesNotExistException, PetalsAdminServiceErrorException,
            ConnectionErrorException, PetalsException, InstanceAlreadyExistsException, MBeanRegistrationException,
            NotCompliantMBeanException {

        assertEquals("Unexpected result", PING_RESULT, this.ping());
    }

    @Override
    public boolean ping() throws PetalsException {

        return this.petalsAdminServiceClient.ping();
    }

    /**
     * Check the interface consistency of {@link PetalsAdminServiceClientImpl#retrieveServerProperties()}
     */
    @Test
    public void testRetrieveServerProperties() throws PetalsAdminDoesNotExistException,
            PetalsAdminServiceErrorException, ConnectionErrorException, PetalsException,
            InstanceAlreadyExistsException, MBeanRegistrationException, NotCompliantMBeanException {

        assertNotNull(this.retrieveServerProperties());
    }

    @Override
    public Properties retrieveServerProperties() throws PetalsException {

        return this.petalsAdminServiceClient.retrieveServerProperties();
    }

    /**
     * Check the interface consistency of {@link PetalsAdminServiceClientImpl#shutdownContainer()}
     */
    @Test
    public void testShutdownContainer() throws PetalsAdminDoesNotExistException, PetalsAdminServiceErrorException,
            ConnectionErrorException, PetalsException, InstanceAlreadyExistsException, MBeanRegistrationException,
            NotCompliantMBeanException {

        this.shutdownContainer();
    }

    @Override
    public void shutdownContainer() throws PetalsException {

        this.petalsAdminServiceClient.shutdownContainer();
    }

    /**
     * Check the interface consistency of {@link PetalsAdminServiceClientImpl#stopContainer()}
     */
    @Test
    public void testStopContainer() throws PetalsAdminDoesNotExistException, PetalsAdminServiceErrorException,
            ConnectionErrorException, PetalsException, InstanceAlreadyExistsException, MBeanRegistrationException,
            NotCompliantMBeanException {

        this.stopContainer();
    }

    @Override
    public void stopContainer() throws PetalsException {

        this.petalsAdminServiceClient.stopContainer();
    }

}
