/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl;

import javax.management.openmbean.CompositeDataSupport;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.jmx.api.api.SystemMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.exception.SystemMonitoringServiceErrorException;

/**
 * <p>
 * Unit tests of {@link SystemMonitoringServiceClientImpl} to check that JMX client interfaces are aligned with the JMX
 * server MBean part.
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class SystemMonitoringServiceClientImplTest extends AbstractServiceClientImpl implements
        SystemMonitoringServiceClient {

    private SystemMonitoringServiceClient systemMonitoringServiceClient;

    @Before
    public void before() throws Exception {
        // The system monitoring MBean is registered by the JVM itself
        this.systemMonitoringServiceClient = jmxClient.getSystemMonitoringServiceClient();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getHeapMemoryUsage()}
     */
    @Test
    public void testGetHeapMemoryUsage() throws SystemMonitoringServiceErrorException {
        this.getHeapMemoryUsage();
    }

    @Override
    public CompositeDataSupport getHeapMemoryUsage() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getHeapMemoryUsage();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getPendingObjects()}
     */
    @Test
    public void testGetPendingObjects() throws SystemMonitoringServiceErrorException {
        this.getPendingObjects();
    }

    @Override
    public int getPendingObjects() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getPendingObjects();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getPeakThreadCount()}
     */
    @Test
    public void testGetPeakThreadCount() throws SystemMonitoringServiceErrorException {
        this.getPeakThreadCount();
    }

    @Override
    public int getPeakThreadCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getPeakThreadCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getDaemonThreadCount()}
     */
    @Test
    public void testGetDaemonThreadCount() throws SystemMonitoringServiceErrorException {
        this.getDaemonThreadCount();
    }

    @Override
    public int getDaemonThreadCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getDaemonThreadCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getThreadCount()}
     */
    @Test
    public void testGetThreadCount() throws SystemMonitoringServiceErrorException {
        this.getThreadCount();
    }

    @Override
    public int getThreadCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getThreadCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getTotalStartedThreadCount()}
     */
    @Test
    public void testGetTotalStartedThreadCount() throws SystemMonitoringServiceErrorException {
        this.getTotalStartedThreadCount();
    }

    @Override
    public long getTotalStartedThreadCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getTotalStartedThreadCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getAvailableProcessors()}
     */
    @Test
    public void testGetAvailableProcessors() throws SystemMonitoringServiceErrorException {
        this.getAvailableProcessors();
    }

    @Override
    public int getAvailableProcessors() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getAvailableProcessors();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getUptime()}
     */
    @Test
    public void testGetUptime() throws SystemMonitoringServiceErrorException {
        this.getUptime();
    }

    @Override
    public long getUptime() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getUptime();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getLoadedClassCount()}
     */
    @Test
    public void testGetLoadedClassCount() throws SystemMonitoringServiceErrorException {
        this.getLoadedClassCount();
    }

    @Override
    public int getLoadedClassCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getLoadedClassCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getTotalLoadedClassCount()}
     */
    @Test
    public void testGetTotalLoadedClassCount() throws SystemMonitoringServiceErrorException {
        this.getTotalLoadedClassCount();
    }

    @Override
    public long getTotalLoadedClassCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getTotalLoadedClassCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getUnloadedClassCount()}
     */
    @Test
    public void testGetUnloadedClassCount() throws SystemMonitoringServiceErrorException {
        this.getUnloadedClassCount();
    }

    @Override
    public long getUnloadedClassCount() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getUnloadedClassCount();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getProcessCpuTime()}
     */
    @Test
    public void testGetProcessCpuTime() throws SystemMonitoringServiceErrorException {
        this.getProcessCpuTime();
    }

    @Override
    public long getProcessCpuTime() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getProcessCpuTime();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getTotalPhysicalMemorySize()}
     */
    @Test
    public void testGetTotalPhysicalMemorySize() throws SystemMonitoringServiceErrorException {
        this.getTotalPhysicalMemorySize();
    }

    @Override
    public long getTotalPhysicalMemorySize() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getTotalPhysicalMemorySize();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getFreePhysicalMemorySize()}
     */
    @Test
    public void testGetFreePhysicalMemorySize() throws SystemMonitoringServiceErrorException {
        this.getFreePhysicalMemorySize();
    }

    @Override
    public long getFreePhysicalMemorySize() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getFreePhysicalMemorySize();
    }

    /**
     * Check the interface consistency of {@link SystemMonitoringServiceClientImpl#getCommittedVirtualMemorySize()}
     */
    @Test
    public void testGetCommittedVirtualMemorySize() throws SystemMonitoringServiceErrorException {
        this.getCommittedVirtualMemorySize();
    }

    @Override
    public long getCommittedVirtualMemorySize() throws SystemMonitoringServiceErrorException {
        return this.systemMonitoringServiceClient.getCommittedVirtualMemorySize();
    }

}
