/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl;

import static org.junit.Assert.assertNotNull;

import java.util.Map;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.basisapi.exception.PetalsException;
import org.ow2.petals.clientserverapi.topology.RemoteContainer;
import org.ow2.petals.clientserverapi.topology.exception.AttachContainerException;
import org.ow2.petals.clientserverapi.topology.exception.DetachContainerException;
import org.ow2.petals.clientserverapi.topology.exception.DomainIsNotDynamicException;
import org.ow2.petals.clientserverapi.topology.exception.InconsistencyException;
import org.ow2.petals.clientserverapi.topology.exception.NoDomainConfigurationProvidedException;
import org.ow2.petals.clientserverapi.topology.exception.NoRemoteContainerProvidedException;
import org.ow2.petals.clientserverapi.topology.exception.NoSecurityPassPhraseProvidedException;
import org.ow2.petals.jmx.api.api.TopologyServiceClient;
import org.ow2.petals.jmx.api.impl.mbean.TopologyService;
import org.ow2.petals.jmx.api.impl.mbean.TopologyServiceMBean;

/**
 * <p>
 * Unit tests of {@link TopologyServiceClientImpl} to check that JMX client interfaces are aligned with the JMX server
 * MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link TopologyServiceMBean} to avoid to forget some methods. A unit test will only invoke
 * the associated method of {@link TopologyServiceMBean}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class TopologyServiceClientImplTest extends AbstractServiceClientImpl implements TopologyServiceMBean {

    private TopologyServiceClient topologyServiceClient;

    @Before
    public void before() throws Exception {
        this.embeddedJmxSrvCon.registerTopologyService(new TopologyService());
        this.topologyServiceClient = jmxClient.getTopologyServiceClient();
    }

    /**
     * Check the interface consistency of {@link TopologyServiceClientImpl#retrieveTopology(String)}
     */
    @Test
    public void testRetrieveTopology() throws Exception {
        assertNotNull(this.retrieveTopology("passphrase", false));
    }

    @Override
    public Set<Map<String, String>> retrieveTopology(final String securityPassPhrase,
            final boolean isSensibleInformationExpected) throws PetalsException {
        return this.topologyServiceClient.retrieveTopology(securityPassPhrase, isSensibleInformationExpected);
    }

    /**
     * Check the interface consistency of {@link TopologyServiceClientImpl#retrieveTopologyObject(String)}
     */
    @Test
    public void testRetrieveTopologyObject() throws Exception {
        assertNotNull(this.retrieveTopologyObject("passphrase", false));
    }

    @Override
    public Object retrieveTopologyObject(final String securityPassPhrase, final boolean isSensibleInformationExpected)
            throws PetalsException {
        return this.topologyServiceClient.retrieveTopologyObject(securityPassPhrase, isSensibleInformationExpected);
    }

    /**
     * Check the interface consistency of
     * {@link TopologyServiceClientImpl#attachContainerTo(ContainerConfiguration, String)}
     */
    @Test
    public void testAttachContainerTo() throws Exception {
        this.attachContainerTo(new RemoteContainer(), "passphrase");
    }

    @Override
    public void attachContainerTo(final RemoteContainer container, final String securityPassPhrase)
            throws NoRemoteContainerProvidedException, NoDomainConfigurationProvidedException,
            DomainIsNotDynamicException, InconsistencyException, NoSecurityPassPhraseProvidedException,
            AttachContainerException {
        this.topologyServiceClient.attachContainerTo(container, securityPassPhrase);
    }

    /**
     * Check the interface consistency of {@link TopologyServiceClientImpl#detachContainer()}
     */
    @Test
    public void testDetachContainerTo() throws Exception {
        this.detachContainer();
    }

    @Override
    public void detachContainer() throws DomainIsNotDynamicException, DetachContainerException {
        this.topologyServiceClient.detachContainer();
    }
}
