/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl.monitoring.component.bc.soap;

import java.util.Map;

import org.junit.Test;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.ComponentMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceDoesNotExistException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.IncomingWsRequestKey;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.OutgoingWsRequestKey;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.PetalsBcSoapMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.soap.WsClientPoolKey;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.component.bc.soap.BcSoapMonitoringService;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.component.framework.ComponentMonitoringService;
import org.ow2.petals.jmx.api.impl.monitoring.component.framework.ComponentMonitoringServiceClientImplTest;

/**
 * <p>
 * Unit tests of {@link BcSoapMonitoringServiceClientImpl} to check that JMX client interfaces are aligned with the JMX
 * server MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link PetalsBcSoapMonitoringServiceClient} to avoid to forget some methods. A unit test
 * will only invoke the associated method of {@link PetalsBcSoapMonitoringServiceClient}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class BcSoapMonitoringServiceClientImplTest extends ComponentMonitoringServiceClientImplTest
        implements PetalsBcSoapMonitoringServiceClient {

    private PetalsBcSoapMonitoringServiceClient bcSoapMonitoringServiceClient;

    @Override
    protected ComponentMonitoringService createComponentMonitoringService() {
        return new BcSoapMonitoringService();
    }

    @Override
    protected ComponentMonitoringServiceClient createComponentMonitoringServiceClient(final String componentId)
            throws ComponentMonitoringServiceErrorException, ComponentMonitoringServiceDoesNotExistException,
            ConnectionErrorException {
        this.bcSoapMonitoringServiceClient = jmxClient.getPetalsBcSoapMonitoringServiceClient(componentId);
        return this.bcSoapMonitoringServiceClient;
    }

    /**
     * Check the interface consistency of {@link BcSoapMonitoringServiceClientImpl#getIncomingWsRequestsCount()}
     */
    @Test
    public void testGetIncomingWsRequestsCount() throws ComponentMonitoringServiceErrorException {
        this.getIncomingWsRequestsCount();
    }

    @Override
    public Map<IncomingWsRequestKey, Long> getIncomingWsRequestsCount() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getIncomingWsRequestsCount();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getInformationHttpRequestsCount()}
     */
    @Test
    public void testGetInformationHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        this.getInformationHttpRequestsCount();
    }

    @Override
    public Long getInformationHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getInformationHttpRequestsCount();
    }

    /**
     * Check the interface consistency of {@link BcSoapMonitoringServiceClientImpl#getUnknownHttpRequestsCount()}
     */
    @Test
    public void testGetUnknownHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        this.getUnknownHttpRequestsCount();
    }

    @Override
    public Long getUnknownHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getUnknownHttpRequestsCount();
    }

    @Override
    public Map<String, Long> getServiceContractsHttpRequestsCount() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getServiceContractsHttpRequestsCount();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getIncomingWsRequestsResponseTimes()}
     */
    @Test
    public void testGetIncomingWsRequestsResponseTimes() throws ComponentMonitoringServiceErrorException {
        this.getIncomingWsRequestsResponseTimes();
    }

    @Override
    public Map<IncomingWsRequestKey, Long[]> getIncomingWsRequestsResponseTimes()
            throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getIncomingWsRequestsResponseTimes();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus()}
     */
    @Test
    public void testGetIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        this.getIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus();
    }

    @Override
    public Map<IncomingWsRequestKey, Long[]> getIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getIncomingWsRequestsResponseTimesGroupedBySvcAndExecStatus();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getHttpServerThreadPoolMetrics()}
     */
    @Test
    public void testGetHttpServerThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        this.getHttpServerThreadPoolMetrics();
    }

    @Override
    public ThreadPoolMetrics getHttpServerThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getHttpServerThreadPoolMetrics();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getWsClientPoolClientsInUseMax()}
     */
    @Test
    public void testGetWsClientPoolClientsInUseMax() throws ComponentMonitoringServiceErrorException {
        this.getWsClientPoolClientsInUseMax();
    }

    @Override
    public Map<WsClientPoolKey, Long> getWsClientPoolClientsInUseMax() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getWsClientPoolClientsInUseMax();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getWsClientPoolClientsInUseCurrent()}
     */
    @Test
    public void testGetWsClientPoolClientsInUseCurrent() throws ComponentMonitoringServiceErrorException {
        this.getWsClientPoolClientsInUseCurrent();
    }

    @Override
    public Map<WsClientPoolKey, Long> getWsClientPoolClientsInUseCurrent()
            throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getWsClientPoolClientsInUseCurrent();
    }

    /**
     * Check the interface consistency of {@link BcSoapMonitoringServiceClientImpl#getWsClientPoolExhaustions()}
     */
    @Test
    public void testGetWsClientPoolExhaustions() throws ComponentMonitoringServiceErrorException {
        this.getWsClientPoolExhaustions();
    }

    @Override
    public Map<WsClientPoolKey, Long> getWsClientPoolExhaustions() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getWsClientPoolExhaustions();
    }

    /**
     * Check the interface consistency of {@link BcSoapMonitoringServiceClientImpl#getOutgoingWsRequestsCount()}
     */
    @Test
    public void testGetOutgoingWsRequestsCount() throws ComponentMonitoringServiceErrorException {
        this.getOutgoingWsRequestsCount();
    }

    @Override
    public Map<OutgoingWsRequestKey, Long> getOutgoingWsRequestsCount() throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getOutgoingWsRequestsCount();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getOutgoingWsRequestsResponseTimes()}
     */
    @Test
    public void testGetOutgoingWsRequestsResponseTimes() throws ComponentMonitoringServiceErrorException {
        this.getOutgoingWsRequestsResponseTimes();
    }

    @Override
    public Map<OutgoingWsRequestKey, Long[]> getOutgoingWsRequestsResponseTimes()
            throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getOutgoingWsRequestsResponseTimes();
    }

    /**
     * Check the interface consistency of
     * {@link BcSoapMonitoringServiceClientImpl#getOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus()}
     */
    @Test
    public void testGetOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        this.getOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus();
    }

    @Override
    public Map<OutgoingWsRequestKey, Long[]> getOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        return this.bcSoapMonitoringServiceClient.getOutgoingWsRequestsResponseTimesGroupedBySvcAndExecStatus();
    }
}