/**
 * Copyright (c) 2014-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl.monitoring.component.framework;

import java.util.Map;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.ComponentMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.ServiceProviderInvocationKey;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceDoesNotExistException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;
import org.ow2.petals.jmx.api.impl.AbstractServiceClientImpl;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.component.framework.ComponentMonitoringService;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.component.framework.ComponentMonitoringServiceMBean;

/**
 * <p>
 * Unit tests of {@link ComponentMonitoringServiceClientImpl} to check that JMX client interfaces are aligned with the
 * JMX server MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link ComponentMonitoringServiceMBean} to avoid to forget some methods. A unit test will
 * only invoke the associated method of {@link ComponentMonitoringServiceMBean}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ComponentMonitoringServiceClientImplTest extends AbstractServiceClientImpl implements
        ComponentMonitoringServiceClient {

    private ComponentMonitoringServiceClient componentMonitoringServiceClient;

    @Before
    public void before() throws Exception {
        this.embeddedJmxSrvCon
                .registerComponentMonitoringService(this.createComponentMonitoringService(), COMPONENT_ID);
        this.componentMonitoringServiceClient = this.createComponentMonitoringServiceClient(COMPONENT_ID);
    }

    protected ComponentMonitoringService createComponentMonitoringService() {
        return new ComponentMonitoringService();
    }

    protected ComponentMonitoringServiceClient createComponentMonitoringServiceClient(final String componentId)
            throws ComponentMonitoringServiceErrorException, ComponentMonitoringServiceDoesNotExistException,
            ConnectionErrorException {
        return jmxClient.getComponentMonitoringServiceClient(componentId);
    }

    /**
     * Check the interface consistency of
     * {@link ComponentMonitoringServiceClientImpl#getServiceProviderInvocationsCount()}
     */
    @Test
    public void testGetServiceProviderInvocationsCount() throws ComponentMonitoringServiceErrorException {
        this.getServiceProviderInvocationsCount();
    }

    @Override
    public Map<ServiceProviderInvocationKey, Long> getServiceProviderInvocationsCount()
            throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getServiceProviderInvocationsCount();
    }

    /**
     * Check the interface consistency of
     * {@link ComponentMonitoringServiceClientImpl#getServiceProviderInvocationsResponseTimes()}
     */
    @Test
    public void testGetServiceProviderInvocationsResponseTimes() throws ComponentMonitoringServiceErrorException {
        this.getServiceProviderInvocationsResponseTimes();
    }

    @Override
    public Map<ServiceProviderInvocationKey, Long[]> getServiceProviderInvocationsResponseTimes()
            throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getServiceProviderInvocationsResponseTimes();
    }

    /**
     * Check the interface consistency of
     * {@link ComponentMonitoringServiceClientImpl#getServiceProviderInvocationsResponseTimesGroupedByItfSvcOpAndExecStatus()}
     */
    @Test
    public void testGetServiceProviderInvocationsResponseTimesGroupedByItfSvcOpAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        this.getServiceProviderInvocationsResponseTimesGroupedByItfSvcOpAndExecStatus();
    }

    @Override
    public Map<ServiceProviderInvocationKey, Long[]> getServiceProviderInvocationsResponseTimesGroupedByItfSvcOpAndExecStatus()
            throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient
                .getServiceProviderInvocationsResponseTimesGroupedByItfSvcOpAndExecStatus();
    }

    /**
     * Check the interface consistency of
     * {@link ComponentMonitoringServiceClientImpl#getMexAcceptorThreadPoolActiveThreadsMaxSize()}
     */
    @Test
    public void testGetMexAcceptorThreadPoolActiveThreadsMaxSize() throws ComponentMonitoringServiceErrorException {
        this.getMexAcceptorThreadPoolActiveThreadsMaxSize();
    }

    @Override
    public Integer getMexAcceptorThreadPoolActiveThreadsMaxSize() throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getMexAcceptorThreadPoolActiveThreadsMaxSize();
    }

    /**
     * Check the interface consistency of
     * {@link ComponentMonitoringServiceClientImpl#getMexAcceptorThreadPoolActiveThreadsCurrentSize()}
     */
    @Test
    public void testGetMexAcceptorThreadPoolActiveThreadsCurrentSize() throws ComponentMonitoringServiceErrorException {
        this.getMexAcceptorThreadPoolActiveThreadsCurrentSize();
    }

    @Override
    public Integer getMexAcceptorThreadPoolActiveThreadsCurrentSize() throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getMexAcceptorThreadPoolActiveThreadsCurrentSize();
    }

    /**
     * Check the interface consistency of
     * {@link ComponentMonitoringServiceClientImpl#getMexProcessorThreadPoolMetrics()}
     */
    @Test
    public void testGetMexProcessorThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        this.getMexProcessorThreadPoolMetrics();
    }

    @Override
    public ThreadPoolMetrics getMexProcessorThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getMexProcessorThreadPoolMetrics();
    }

    /**
     * Check the interface consistency of {@link ComponentMonitoringServiceClientImpl#getMexAcceptorWorkingCurrent()}
     */
    @Test
    public void testGetMexAcceptorWorkingCurrent() throws ComponentMonitoringServiceErrorException {
        this.getMexAcceptorWorkingCurrent();
    }

    @Override
    public Long getMexAcceptorWorkingCurrent() throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getMexAcceptorWorkingCurrent();
    }

    /**
     * Check the interface consistency of {@link ComponentMonitoringServiceClientImpl#getMexAcceptorWorkingMax()}
     */
    @Test
    public void testGetMexAcceptorWorkingMax() throws ComponentMonitoringServiceErrorException {
        this.getMexAcceptorWorkingMax();
    }

    @Override
    public Long getMexAcceptorWorkingMax() throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getMexAcceptorWorkingMax();
    }

    /**
     * Check the interface consistency of {@link ComponentMonitoringServiceClientImpl#getMexAcceptorRelativeDurations()}
     */
    @Test
    public void testGetMexAcceptorRelativeDurations() throws ComponentMonitoringServiceErrorException {
        this.getMexAcceptorRelativeDurations();
    }

    @Override
    public Long[] getMexAcceptorRelativeDurations() throws ComponentMonitoringServiceErrorException {
        return this.componentMonitoringServiceClient.getMexAcceptorRelativeDurations();
    }

}
