/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl.monitoring.component.se.flowable;

import java.util.Map;

import org.junit.Test;
import org.ow2.petals.jmx.api.api.exception.ConnectionErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.ComponentMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceDoesNotExistException;
import org.ow2.petals.jmx.api.api.monitoring.component.framework.exception.ComponentMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.api.monitoring.component.se.flowable.DatabaseConnectionPoolMetrics;
import org.ow2.petals.jmx.api.api.monitoring.component.se.flowable.SeFlowableMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.object.ThreadPoolMetrics;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.component.framework.ComponentMonitoringService;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.component.se.SeFlowableMonitoringService;
import org.ow2.petals.jmx.api.impl.monitoring.component.bc.soap.BcSoapMonitoringServiceClientImpl;
import org.ow2.petals.jmx.api.impl.monitoring.component.framework.ComponentMonitoringServiceClientImplTest;
import org.ow2.petals.jmx.api.impl.monitoring.component.se.flowable.SeFlowableMonitoringServiceClientImpl;

/**
 * <p>
 * Unit tests of {@link BcSoapMonitoringServiceClientImpl} to check that JMX client interfaces are aligned with the JMX
 * server MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link SeFlowableMonitoringServiceClient} to avoid to forget some methods. A unit test will
 * only invoke the associated method of {@link SeFlowableMonitoringServiceClient}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class SeFlowableMonitoringServiceClientImplTest extends ComponentMonitoringServiceClientImplTest
        implements SeFlowableMonitoringServiceClient {

    private SeFlowableMonitoringServiceClient seFlowableMonitoringServiceClient;

    @Override
    protected ComponentMonitoringService createComponentMonitoringService() {
        return new SeFlowableMonitoringService();
    }

    @Override
    protected ComponentMonitoringServiceClient createComponentMonitoringServiceClient(final String componentId)
            throws ComponentMonitoringServiceErrorException, ComponentMonitoringServiceDoesNotExistException,
            ConnectionErrorException {
        this.seFlowableMonitoringServiceClient = jmxClient.getSeFlowableMonitoringServiceClient(componentId);
        return this.seFlowableMonitoringServiceClient;
    }

    /**
     * Check the interface consistency of
     * {@link SeFlowableMonitoringServiceClientImpl#getAsyncExecutorThreadPoolMetrics()}
     */
    @Test
    public void testGetAsyncExecutorThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        this.getAsyncExecutorThreadPoolMetrics();
    }

    @Override
    public ThreadPoolMetrics getAsyncExecutorThreadPoolMetrics() throws ComponentMonitoringServiceErrorException {
        return this.seFlowableMonitoringServiceClient.getAsyncExecutorThreadPoolMetrics();
    }

    /**
     * Check the interface consistency of {@link SeFlowableMonitoringServiceClientImpl#getProcessDefinitions()}
     */
    @Test
    public void testGetProcessDefinitions() throws ComponentMonitoringServiceErrorException {
        this.getProcessDefinitions();
    }

    @Override
    public Map<String, Long[]> getProcessDefinitions() throws ComponentMonitoringServiceErrorException {
        return this.seFlowableMonitoringServiceClient.getProcessDefinitions();
    }

    /**
     * Check the interface consistency of
     * {@link SeFlowableMonitoringServiceClientImpl#getDatabaseConnectionPoolMetrics()}
     */
    @Test
    public void testGetDatabaseConnectionPoolMetrics() throws ComponentMonitoringServiceErrorException {
        this.getDatabaseConnectionPoolMetrics();
    }

    @Override
    public DatabaseConnectionPoolMetrics getDatabaseConnectionPoolMetrics()
            throws ComponentMonitoringServiceErrorException {
        return this.seFlowableMonitoringServiceClient.getDatabaseConnectionPoolMetrics();
    }
}
