/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.impl.monitoring.container.local;

import org.junit.Before;
import org.junit.Test;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.local.DeliveredMessages;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.local.LocalTransporterMonitoringServiceClient;
import org.ow2.petals.jmx.api.api.monitoring.container.transporter.local.exception.LocalTransporterMonitoringServiceErrorException;
import org.ow2.petals.jmx.api.impl.AbstractServiceClientImpl;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.container.transport.local.LocalTransporterMonitoringService;
import org.ow2.petals.jmx.api.impl.mbean.monitoring.container.transport.local.LocalTransporterMonitoringServiceMBean;
import org.ow2.petals.jmx.api.impl.monitoring.container.transport.local.LocalTransporterMonitoringServiceClientImpl;

/**
 * <p>
 * Unit tests of {@link LocalTransporterMonitoringServiceClientImpl} to check that JMX client interfaces are aligned
 * with the JMX server MBean part.
 * </p>
 * <p>
 * This unit tests implement {@link LocalTransporterMonitoringServiceMBean} to avoid to forget some methods. A unit test
 * will only invoke the associated method of {@link LocalTransporterMonitoringServiceMBean}
 * </p>
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class LocalTransporterMonitoringServiceClientImplTest extends AbstractServiceClientImpl
        implements LocalTransporterMonitoringServiceClient {

    private LocalTransporterMonitoringServiceClient localTransporterMonitoringServiceClient;

    @Before
    public void before() throws Exception {
        this.embeddedJmxSrvCon.registerLocalTransporterMonitoringService(new LocalTransporterMonitoringService());
        this.localTransporterMonitoringServiceClient = this.jmxClient.getLocalTransporterMonitoringServiceClient();
    }

    /**
     * Check the interface consistency of {@link LocalTransporterMonitoringServiceClientImpl#getDeliveredMessage()}
     */
    @Test
    public void testGetDeliveredMessage() throws LocalTransporterMonitoringServiceErrorException {
        this.getDeliveredMessage();
    }

    @Override
    public DeliveredMessages getDeliveredMessage() throws LocalTransporterMonitoringServiceErrorException {
        return this.localTransporterMonitoringServiceClient.getDeliveredMessage();
    }

}
